@@ -1,14 +1,13 @@
-NadarayaWatsonkernel <-
-function(x, y, h, gridpoint)
+NadarayaWatsonkernel <- function(x, y, h, gridpoint)
 {
-  n=length(y)
+  n = length(y)
   mh = vector(,length(gridpoint))
   for(j in 1:length(gridpoint))
   {
-      suma=sumb=vector(,n)
+      suma = sumb = vector(,n)
       for(i in 1:n)
       {
-          suma[i] = ker((gridpoint[j] - x[i])/h)*y[i]
+          suma[i] = ker((gridpoint[j] - x[i])/h) * y[i]
           sumb[i] = ker((gridpoint[j] - x[i])/h)
       }
       mh[j] = sum(suma)/sum(sumb)
